==> jc-1.4.0.tar.gz: ppg/cmds/ExtendCmd.h <==
// public class ppg.cmds.ExtendCmd

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 60da298ed5808672 ppg_cmds_ExtendCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_ExtendCmd_H_
#define _JC_ppg_cmds_ExtendCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_ExtendCmd$sub_refs	_jc_ppg_cmds_ExtendCmd$sub_refs;
typedef struct _jc_ppg_cmds_ExtendCmd$sub_nonrefs	_jc_ppg_cmds_ExtendCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_ExtendCmd$refs	_jc_ppg_cmds_ExtendCmd$refs;
typedef struct _jc_ppg_cmds_ExtendCmd$nonrefs	_jc_ppg_cmds_ExtendCmd$nonrefs;
typedef struct _jc_ppg_cmds_ExtendCmd$object	_jc_ppg_cmds_ExtendCmd$object;

typedef const struct _jc_ppg_cmds_ExtendCmd$vmethods	_jc_ppg_cmds_ExtendCmd$vmethods;
typedef const struct _jc_ppg_cmds_ExtendCmd$vtable	_jc_ppg_cmds_ExtendCmd$vtable;
typedef const struct _jc_ppg_cmds_ExtendCmd$vtype	_jc_ppg_cmds_ExtendCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_ExtendCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_atoms_Production$object *);

// Virtual methods
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_ExtendCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *);
extern void _jc_ppg_cmds_ExtendCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_ExtendCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_ExtendCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_ExtendCmd$vmethods {
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_cmds_ExtendCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_ExtendCmd$vmethods	ppg_cmds_ExtendCmd;
};

// Vtype
struct _jc_ppg_cmds_ExtendCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_ExtendCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_ExtendCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_ExtendCmd$refs {
    _jc_ppg_cmds_ExtendCmd$sub_refs	ppg_cmds_ExtendCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_ExtendCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_ExtendCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_ExtendCmd$sub_nonrefs	ppg_cmds_ExtendCmd;
};

// Object instance structure
struct _jc_ppg_cmds_ExtendCmd$object {
	_jc_ppg_cmds_ExtendCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_ExtendCmd$vtype	*vtype;
	_jc_ppg_cmds_ExtendCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_ExtendCmd$vtype _jc_ppg_cmds_ExtendCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_ExtendCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_ExtendCmd$class_object;

#endif	/* _JC_ppg_cmds_ExtendCmd_H_ */

==> jc-1.4.6.tar.gz: ppg/cmds/ExtendCmd.h <==
// public class ppg.cmds.ExtendCmd

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 60da298ed5808672 ppg_cmds_ExtendCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_ExtendCmd_H_
#define _JC_ppg_cmds_ExtendCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_ExtendCmd$sub_refs	_jc_ppg_cmds_ExtendCmd$sub_refs;
typedef struct _jc_ppg_cmds_ExtendCmd$sub_nonrefs	_jc_ppg_cmds_ExtendCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_ExtendCmd$refs	_jc_ppg_cmds_ExtendCmd$refs;
typedef struct _jc_ppg_cmds_ExtendCmd$nonrefs	_jc_ppg_cmds_ExtendCmd$nonrefs;
typedef struct _jc_ppg_cmds_ExtendCmd$object	_jc_ppg_cmds_ExtendCmd$object;

typedef const struct _jc_ppg_cmds_ExtendCmd$vmethods	_jc_ppg_cmds_ExtendCmd$vmethods;
typedef const struct _jc_ppg_cmds_ExtendCmd$vtable	_jc_ppg_cmds_ExtendCmd$vtable;
typedef const struct _jc_ppg_cmds_ExtendCmd$vtype	_jc_ppg_cmds_ExtendCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_ExtendCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_atoms_Production$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_ExtendCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_cmds_ExtendCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_ExtendCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_ExtendCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_ExtendCmd$vmethods {
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_ExtendCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_cmds_ExtendCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_ExtendCmd$vmethods	ppg_cmds_ExtendCmd;
};

// Vtype
struct _jc_ppg_cmds_ExtendCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_ExtendCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_ExtendCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_ExtendCmd$refs {
    _jc_ppg_cmds_ExtendCmd$sub_refs	ppg_cmds_ExtendCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_ExtendCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_ExtendCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_ExtendCmd$sub_nonrefs	ppg_cmds_ExtendCmd;
};

// Object instance structure
struct _jc_ppg_cmds_ExtendCmd$object {
	_jc_ppg_cmds_ExtendCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_ExtendCmd$vtype	*vtype;
	_jc_ppg_cmds_ExtendCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_ExtendCmd$vtype _jc_ppg_cmds_ExtendCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_ExtendCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_ExtendCmd$class_object;

#endif	/* _JC_ppg_cmds_ExtendCmd_H_ */
